Chaussette
==========

Chaussette is a WSGI server.

Links:

- The full documentation is located at : http://chaussette.readthedocs.org
- You can reach us for any feedback, bug report, or to contribute, at
  https://github.com/mozilla-services/chaussette
